@@ -53,7 +53,8 @@
 #' @param coef.keep.zeros logical Keep or drop trailing zeros when formatting
 #'   the fitted coefficients and F-value.
 #' @param rr.digits,p.digits integer Number of digits after the decimal point to
-#'   use for \eqn{R^2} and P-value in labels.
+#'   use for \eqn{R^2} and P-value in labels. If \code{Inf}, use exponential
+#'   notation with three decimal places.
 #' @param label.x,label.y \code{numeric} with range 0..1 "normalized parent
 #'   coordinates" (npc units) or character if using \code{geom_text_npc()} or
 #'   \code{geom_label_npc()}. If using \code{geom_text()} or \code{geom_label()}
@@ -863,9 +864,18 @@ poly_eq_compute_group_fun <- function(data,
       AIC.char <- sprintf_dm("\"%.4g\"", AIC, decimal.mark = decimal.mark)
       BIC.char <- sprintf_dm("\"%.4g\"", BIC, decimal.mark = decimal.mark)
       f.value.char <- sprintf_dm("\"%#.*g\"", f.digits, f.value, decimal.mark = decimal.mark)
+      if (grepl("e", f.value.char)) {
+        f.value.char <- sprintf_dm("%#.*e", f.digits, f.value, decimal.mark = decimal.mark)
+        f.value.char <- paste(gsub("e", " %*% 10^{", f.value.char), "}", sep = "")
+      }
       f.df1.char <- as.character(f.df1)
       f.df2.char <- as.character(f.df2)
-      p.value.char <- sprintf_dm("\"%#.*f\"", p.digits, p.value, decimal.mark = decimal.mark)
+      if (p.digits == Inf) {
+        p.value.char <- sprintf_dm("%#.2e", p.value, decimal.mark = decimal.mark)
+        p.value.char <- paste(gsub("e", " %*% 10^{", p.value.char), "}", sep = "")
+      } else {
+        p.value.char <- sprintf_dm("\"%#.*f\"", p.digits, p.value, decimal.mark = decimal.mark)
+      }
     } else {
       rr.char <- sprintf_dm("%#.*f", rr.digits, rr, decimal.mark = decimal.mark)
       adj.rr.char <- sprintf_dm("%#.*f", rr.digits, adj.rr, decimal.mark = decimal.mark)
@@ -885,7 +895,11 @@ poly_eq_compute_group_fun <- function(data,
       f.value.char <- sprintf_dm("%#.*g", f.digits, f.value, decimal.mark = decimal.mark)
       f.df1.char <- as.character(f.df1)
       f.df2.char <- as.character(f.df2)
-      p.value.char <- sprintf_dm("%#.*f", p.digits, p.value, decimal.mark = decimal.mark)
+      if (p.digits == Inf) {
+        p.value.char <- sprintf_dm("%#.2e", p.value, decimal.mark = decimal.mark)
+      } else {
+        p.value.char <- sprintf_dm("%#.*f", p.digits, p.value, decimal.mark = decimal.mark)
+      }
     }
 
     # build the data frames to return
